- Überblick
- Anforderungen
- Installation
- Fragen und Antworten: Bereitstellungsvorlagen
- Herunterladen der Installationspakete
- install-uipath.sh-Parameter
- Aktivieren eines High Availability Add-ons für den Cluster
- Document Understanding-Konfigurationsdatei
- Hinzufügen eines dedizierten Agent-Knotens mit GPU-Unterstützung
- Verbinden einer Task Mining-Anwendung
- Hinzufügen eines dedizierten Agent-Knotens für Task Mining
- Nach der Installation
- Clusterverwaltung
- Verwalten von Produkten
- Verwalten des Clusters in ArgoCD
- Einrichten des externen NFS-Servers
- Automatisiert: Aktivieren der Sicherung im Cluster
- Automatisiert: Deaktivieren der Clustersicherung
- Automatisiert, online: Wiederherstellen des Clusters
- Automatisiert, offline: Wiederherstellen des Clusters
- Manuell: Aktivieren der Clustersicherung
- Manuell: Deaktivieren der Clustersicherung
- Manuell, online: Wiederherstellen des Clusters
- Manuell, offline: Wiederherstellen des Clusters
- Zusätzliche Konfiguration
- Migrieren von Objectstore von persistentem Volume zu Raw-Festplatten
- Überwachung und Warnungen
- Migration und Upgrade
- Migrationsoptionen
- Schritt 1: Verschieben der Identitätsorganisationsdaten von einer eigenständigen in die Automation Suite
- Schritt 2: Wiederherstellen der eigenständigen Produktdatenbank
- Schritt 3: Sichern der Plattformdatenbank in der Automation Suite
- Schritt 4: Zusammenführen von Organisationen in der Automation Suite
- Schritt 5: Aktualisieren der migrierten Produktverbindungszeichenfolgen
- Schritt 6: Migrieren von eigenständigen Insights
- Schritt 7: Löschen des Standardmandanten
- Durchführen der Migration eines einzelnen Mandanten
- Produktspezifische Konfiguration
- Best Practices und Wartung
- Fehlersuche und ‑behebung
- Fehlerbehebung bei Diensten während der Installation
- Deinstallieren des Clusters
- Löschen von Offline-Artefakten für mehr Speicherplatz
- So löschen Sie Redis-Daten
- So können Sie die Istio-Protokollierung aktivieren
- So werden Protokolle manuell bereinigt
- So löschen Sie alte Protokolle, die im sf-logs-Bucket gespeichert sind
- So deaktivieren Sie Streaming-Protokolle für das AI Center
- Fehlerbehebung bei fehlgeschlagenen Automation Suite-Installationen
- So löschen Sie Bilder aus dem alten Installationsprogramm nach dem Upgrade
- Automatisches Bereinigen von Longhorn-Snapshots
- Deaktivieren von TX-Prüfsummen-Offloading
- Umgang mit schwachen Verschlüsselungen in TLS 1.2
- Es kann keine Offlineinstallation auf RHEL 8.4 OS ausgeführt werden.
- Fehler beim Herunterladen des Pakets
- Die Offlineinstallation schlägt aufgrund fehlender binärer Dateien fehl
- Zertifikatproblem bei der Offlineinstallation
- Die erste Installation schlägt während des Longhorn-Setups fehl
- Validierungsfehler bei der SQL-Verbindungszeichenfolge
- Voraussetzungsprüfung für das Selinux-iscsid-Modul schlägt fehl
- Azure-Datenträger nicht als SSD markiert
- Fehler nach der Zertifikatsaktualisierung
- Automation Suite funktioniert nach Betriebssystem-Upgrade nicht
- Für die Automation Suite muss Backlog_wait_time festgelegt werden 1
- Volume nicht bereitstellbar, da es nicht für Workloads bereit ist
- RKE2 schlägt während der Installation und Aktualisierung fehl
- Fehler beim Hoch- oder Herunterladen von Daten im Objektspeicher
- Die Größenänderung eines PVC bewirkt keine Korrektur von Ceph
- Fehler beim Ändern der Größe von objectstore PVC
- Rook Ceph oder Looker-Pod hängen im Init-Status fest
- Fehler beim Anhängen eines StatefulSet-Volumes
- Fehler beim Erstellen persistenter Volumes
- Patch zur Rückgewinnung von Speicherplatz
- Sicherung aufgrund des Fehlers „TooManySnapshots“ fehlgeschlagen
- Alle Longhorn-Replikate sind fehlerhaft
- Festlegen eines Timeout-Intervalls für die Verwaltungsportale
- Aktualisieren Sie die zugrunde liegenden Verzeichnisverbindungen
- Anmeldung nach der Migration nicht mehr möglich
- Kinit: KDC kann für Realm <AD Domain> beim Abrufen der ersten Anmeldeinformationen nicht gefunden werden
- Kinit: Keytab enthält keine geeigneten Schlüssel für *** beim Abrufen der ersten Anmeldeinformationen
- Der GSSAPI-Vorgang ist mit Fehler fehlgeschlagen: Es wurde ein ungültiger Statuscode übermittelt (Die Anmeldeinformationen des Clients wurden widerrufen).
- Alarm für fehlgeschlagenen Kerberos-tgt-update-Auftrag empfangen
- SSPI-Anbieter: Server nicht in Kerberos-Datenbank gefunden
- Die Anmeldung ist für den Benutzer <ADDOMAIN><aduser> fehlgeschlagen. Grund: Das Konto ist deaktiviert.
- ArgoCD-Anmeldung fehlgeschlagen
- Fehler beim Abrufen des Sandbox-Abbilds
- Pods werden nicht in der ArgoCD-Benutzeroberfläche angezeigt
- Redis-Testfehler
- RKE2-Server kann nicht gestartet werden
- Secret nicht im UiPath-Namespace gefunden
- Nach der ersten Installation wechselte ArgoCD in den Status „Progressing“.
- MongoDB-Pods in „CrashLoopBackOff“ oder ausstehende PVC-Bereitstellung nach Löschung
- UNERWARTETE INKONSISTENZ; fsck MANUELL AUSFÜHREN
- Herabgestufte MongoDB- oder Geschäftsanwendungen nach der Clusterwiederherstellung
- Self-heal-operator und Sf-k8-utils-Repository fehlen
- Fehlerhafte Dienste nach Clusterwiederherstellung oder Rollback
- RabbitMQ-Pod bleibt in CrashLoopBackOff hängen
- Prometheus im Zustand „CrashloopBackoff“ mit OOM-Fehler (Out-of-Memory)
- Fehlende Ceph-rook-Metriken in Überwachungs-Dashboards
- Pods können nicht mit FQDN in einer Proxy-Umgebung kommunizieren
- Document Understanding erscheint nicht auf der linken Leiste der Automation Suite
- Fehlerstatus beim Erstellen einer Datenbeschriftungssitzung
- Fehlerstatus beim Versuch, eine ML-Fähigkeit bereitzustellen
- Migrationsauftrag schlägt in ArgoCD fehl
- Die Handschrifterkennung mit dem Intelligent Form Extractor funktioniert nicht oder arbeitet zu langsam
- Verwenden des Automation Suite-Diagnosetools
- Verwenden des Automation Suite-Supportpakets
- Erkunden von Protokollen
install-uipath.sh-Parameter
Mit dem manuellen Installationsprogramm install-uipath.sh können Sie die Installationsumgebung anpassen, ohne das interaktive Installationsprogramm ( installUiPathAS.sh ) auszuführen.
Während das manuelle Installationsprogramm für erweiterte Szenarien geeignet ist, sind die Bereitstellungsvorlagen und das interaktive Installationsprogramm immer noch die empfohlenen Optionen.
The install-uipath.sh installer is available in sf-installer.zip. For download instructions, see Downloading installation packages.
Erforderliche Parameter
--input -i <string>
Geben Sie die .json-Eingabedatei an.
input.json refers to the cluster_config.json that defines the parameters, settings, and preferences applied to the UiPath® services deployed via Automation Suite. You need to update this file to change the defaults and use any advanced configuration for your cluster. For details, refer to Manual: Advanced installation experience.
--output -o <string>
Geben Sie die .json-Ausgabedatei an.
output.json bezieht sich auf die Ausgabedatei des manuellen Installationsprogramms.
Optionale Parameter
--install-kubernetes -k
Installieren Sie den Kubernetes-Cluster.
--join-node -j <server|agent>
Wird nur mit -k verwendet. Bestimmt den Typ des Knotens, der mit einem vorhandenen Cluster verbunden werden soll. Zulässige Werte: <server|agent>.
--install-fabric -f
Installieren Sie die Fabric-Komponenten.
--install-services -s
Installieren Sie die UiPath-Dienste.
--install-all -a
Führen Sie alle Installationsprogramme in der richtigen Reihenfolge aus. Wenn keine Installation explizit ausgewählt ist, wird –install-all angenommen.
--install-type <online|offline>
Geben Sie den Installationstyp an. Standard ist online . Sie können ihn nicht zusammen mit –offline-bundle auf online festlegen.
--offline-bundle <string>
Geben Sie den Pfad zum Offlinepaket an. Zeigt an, dass die Installationsmethode „Tarball“ ist.
--offline-tmp-folder <string>
Optionales Flag, das mit --offline-bundle oder --optional-offline-bundle verwendet werden kann. Geben Sie das übergeordnete Verzeichnis für den temporären Offlineinstallationsordner an. Die Standardeinstellung ist /tmp.
--optional-offline-bundle <string>
Geben Sie den Pfad zum optionalen Offlinepaket an.
--pre-reqs -p
Kontrollieren Sie die Voraussetzungen. Wenn Sie dieses Flag verwenden, können keine anderen Flags übergeben werden.
--install-offline-prereqs
Wird bei der Tarball-Installationsmethode verwendet und installiert alle Voraussetzungen.
--skip-packages-install
Überspringt die Installation der Voraussetzungen bei der Online-Installationsmethode. Standardmäßig werden die Voraussetzungen installiert.
--upgrade -u
Aktualisiert einen vorhandenen Automation Suite-Cluster.
--kubeconfig <string>
Gibt den Pfad zur kubeconfig-Datei an. Wenn dieses Flag fehlt, wird er standardmäßig /etc/rancher/rke2/rke2.yaml.
--backup -b
Sichern Sie den Cluster.
--restore -r
Stellen Sie den Cluster wieder her.
--restore-volume
Stellt das Volume wieder her.
--disable-backup
Deaktivieren Sie die Sicherung.
-d
Im Debugmodus ausführen.
-h
Zeigt Hilfe an.
--accept-license-agreement
Obligatorisches Flag zum Akzeptieren der Lizenzvereinbarung.
-c
Installieren Sie Cilium CNI (Container Network Interface), um das Standard-Canal zu ersetzen. Wird nur während des Upgrades verwendet. Sie können es nicht mit einem Installations-Flag verwenden.
--skip-pre-reqs
Überspringen Sie die Überprüfung der Voraussetzungen während der Installation.
--install-standalone-aicenter
Installieren Sie nur den eigenständigen AI Center-Dienst.
--one-time-manual-backup
Lösen Sie die manuelle Sicherung aus und deaktivieren Sie sie nach Abschluss.
-m|--machines <comma separated machine's IP>
Geben Sie die Zielmaschinen für die Installation an. Geben Sie durch Kommas getrennte IP-Adressen oder Hostnamen aller Maschinen an.
--compare-config
Vergleichen Sie die aktuelle Konfigurationsdatei mit dem Clusterstatus. Es vergleicht die Datei input.json mit der aktuellen Clusterkonfiguration.
--skip-compare-config
Überspringen Sie den Vergleich der aktuellen Konfiguration mit dem Clusterstatus.
Beispiele
-
Installieren der Kubernetes-Clusterkomponenten auf der VM, wo sie ausgeführt wird, mithilfe der Onlineinstallationsmethode.
install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement -
Installieren der Kubernetes-Komponenten auf der VM, auf der sie ausgeführt wird, und verbinden mit dem vorhandenen Cluster als Server mithilfe der Onlineinstallationsmethode.
install-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreement -
Führen Sie die vollständige Installation auf der aktuellen VM mit der Online-Installationsmethode durch. Enthält die Kubernetes-Clusterkomponenten, die Fabric- und die Uipath-Dienste.
install-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreement -
Ausführen der vollständigen Installation auf der aktuellen VM mithilfe der Online-Installationsmethode. Überspringen Sie diesmal die Installation der Voraussetzungen.
install-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreement -
Ausführen der Kubernetes-Clusterinstallation mithilfe der Tarball-Installationsmethode. Verbinden Sie außerdem den Knoten mit dem vorhandenen Cluster und installieren Sie alle Offline-Voraussetzungen.
install-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement --install-offline-prereqsinstall-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement --install-offline-prereqs -
Installieren der Fabric- und Dienstkomponenten mithilfe der Offlineinstallationsmethode, ohne dass ein temporärer Ordner angegeben ist.
install-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement -
Ausführen des Installationsprogramms für eine Offlineinstallation, ohne jedoch die Artefakte zu laden.
install-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreement -
Führen Sie das Installationsprogramm aus und überspringen Sie die Prüfung der Voraussetzungen
install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqsinstall-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqs
- Erforderliche Parameter
--input -i <string>--output -o <string>- Optionale Parameter
--install-kubernetes -k--join-node -j <server|agent>--install-fabric -f--install-services -s--install-all -a--install-type <online|offline>--offline-bundle <string>--offline-tmp-folder <string>--optional-offline-bundle <string>--pre-reqs -p--install-offline-prereqs--skip-packages-install--upgrade -u--kubeconfig <string>--backup -b--restore -r--restore-volume--disable-backup-d-h--accept-license-agreement-c--skip-pre-reqs--install-standalone-aicenter--one-time-manual-backup-m|--machines <comma separated machine's IP>--compare-config--skip-compare-config- Beispiele